@@ -340,11 +340,11 @@ class BOTAN_PUBLIC_API(2,0) Compat_Callbacks final : public Callbacks
       typedef std::function<std::string (std::vector<std::string>)> next_protocol_fn;
 
       /**
-       * @param output_fn is called with data for the outbound socket
+       * @param data_output_fn is called with data for the outbound socket
        *
        * @param app_data_cb is called when new application data is received
        *
-       * @param alert_cb is called when a TLS alert is received
+       * @param recv_alert_cb is called when a TLS alert is received
        *
        * @param hs_cb is called when a handshake is completed
        *
@@ -353,40 +353,43 @@ class BOTAN_PUBLIC_API(2,0) Compat_Callbacks final : public Callbacks
        * @param next_proto is called with ALPN protocol data sent by the client
        */
        BOTAN_DEPRECATED("Use TLS::Callbacks (virtual interface).")
-       Compat_Callbacks(output_fn output_fn, data_cb app_data_cb, alert_cb alert_cb,
+       Compat_Callbacks(output_fn data_output_fn, data_cb app_data_cb, alert_cb recv_alert_cb,
                         handshake_cb hs_cb, handshake_msg_cb hs_msg_cb = nullptr,
                         next_protocol_fn next_proto = nullptr)
-          : m_output_function(output_fn), m_app_data_cb(app_data_cb),
-            m_alert_cb(std::bind(alert_cb, std::placeholders::_1, nullptr, 0)),
+          : m_output_function(data_output_fn), m_app_data_cb(app_data_cb),
+            m_alert_cb(std::bind(recv_alert_cb, std::placeholders::_1, nullptr, 0)),
             m_hs_cb(hs_cb), m_hs_msg_cb(hs_msg_cb), m_next_proto(next_proto) {}
 
        BOTAN_DEPRECATED("Use TLS::Callbacks (virtual interface).")
-       Compat_Callbacks(output_fn output_fn, data_cb app_data_cb,
-                        std::function<void (Alert)> alert_cb,
+       Compat_Callbacks(output_fn data_output_fn, data_cb app_data_cb,
+                        std::function<void (Alert)> recv_alert_cb,
                         handshake_cb hs_cb,
                         handshake_msg_cb hs_msg_cb = nullptr,
                         next_protocol_fn next_proto = nullptr)
-          : m_output_function(output_fn), m_app_data_cb(app_data_cb),
-            m_alert_cb(alert_cb),
+          : m_output_function(data_output_fn), m_app_data_cb(app_data_cb),
+            m_alert_cb(recv_alert_cb),
             m_hs_cb(hs_cb), m_hs_msg_cb(hs_msg_cb), m_next_proto(next_proto) {}
 
        enum class SILENCE_DEPRECATION_WARNING { PLEASE = 0 };
        Compat_Callbacks(SILENCE_DEPRECATION_WARNING,
-                        output_fn output_fn, data_cb app_data_cb,
-                        std::function<void (Alert)> alert_cb,
+                        output_fn data_output_fn, data_cb app_data_cb,
+                        std::function<void (Alert)> recv_alert_cb,
                         handshake_cb hs_cb,
                         handshake_msg_cb hs_msg_cb = nullptr,
                         next_protocol_fn next_proto = nullptr)
-          : m_output_function(output_fn), m_app_data_cb(app_data_cb),
-            m_alert_cb(alert_cb),
-            m_hs_cb(hs_cb), m_hs_msg_cb(hs_msg_cb), m_next_proto(next_proto) {}
+          : m_output_function(data_output_fn),
+            m_app_data_cb(app_data_cb),
+            m_alert_cb(recv_alert_cb),
+            m_hs_cb(hs_cb),
+            m_hs_msg_cb(hs_msg_cb),
+            m_next_proto(next_proto) {}
 
        Compat_Callbacks(SILENCE_DEPRECATION_WARNING,
-                        output_fn output_fn, data_cb app_data_cb, alert_cb alert_cb,
+                        output_fn data_output_fn, data_cb app_data_cb, alert_cb recv_alert_cb,
                         handshake_cb hs_cb, handshake_msg_cb hs_msg_cb = nullptr,
                         next_protocol_fn next_proto = nullptr)
-          : m_output_function(output_fn), m_app_data_cb(app_data_cb),
-            m_alert_cb(std::bind(alert_cb, std::placeholders::_1, nullptr, 0)),
+          : m_output_function(data_output_fn), m_app_data_cb(app_data_cb),
+            m_alert_cb(std::bind(recv_alert_cb, std::placeholders::_1, nullptr, 0)),
             m_hs_cb(hs_cb), m_hs_msg_cb(hs_msg_cb), m_next_proto(next_proto) {}
 
 
